@@ -1,6 +1,6 @@
 /*-*-c++-*-*****************************************************************
                              -------------------
-    cvs         : $Id: algorithms.h,v 1.7 2005/04/20 11:03:32 cstim Exp $
+    cvs         : $Id: algorithms.h,v 1.8 2005/11/16 12:19:16 cstim Exp $
     begin       : Sat Aug 10 2002
     copyright   : (C) 2002, 2003 by Fabian Kaiser and Christian Stimming
     email       : fabian@openhbci.de
@@ -64,12 +64,12 @@ int    algo03(int modulus, int weight[10], bool crossfoot, int accountId[10],
 			  int startAdd, int stopAdd);
 int    algo03a(int weight[10], bool crossfoot, int accountId[10], 
 			  int startAdd, int stopAdd);
+int    algo05(int modulus1, int modulus2, int weight[10], int accountId[10],
+			  int startAdd, int stopAdd);
 AccountNumberCheck::Result 
 algo04(const std::string& bankId, std::string accountId);
 AccountNumberCheck::Result 
 algo04a(const std::string& bankId, std::string accountId);
-AccountNumberCheck::Result 
-algo05(const std::string& accountId);
 AccountNumberCheck::Result
 algo06(const std::string& accountId);
 AccountNumberCheck::Result
