@@ -444,10 +444,23 @@ AccountNumberCheck::Result method_50(int *account, int *weight) {
 	return algo01(11, weight, false, 7, account);
     }
 }
+// This is not an individual method, but this code is quite popolar.
+// successfully checked with positive and negative samples.
+AccountNumberCheck::Result method_51_exception(int *account, int *weight) {
+	number2Array("0087654320", weight);
+	if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
+	    return AccountNumberCheck::OK;		// Variant 1
+	number2Array("0987654320", weight); weight[0] = 10;
+	return algo01(11, weight, false, 10, account);	// Variant 2
+}
 // Added by Jens Gecius, validated with six test accountIDs
 // Checked with positive numbers for methods A, B, C
 // Exception handling see below
 AccountNumberCheck::Result method_51(int *account, int *weight) {
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
+
     number2Array("0007654320", weight);
     if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
 	return AccountNumberCheck::OK;	// Method A
@@ -456,20 +469,6 @@ AccountNumberCheck::Result method_51(int *account, int *weight) {
 	return AccountNumberCheck::OK;  // Method B
     if (7 == account[9] || 8 == account[9] || 9 == account[9])
 	return AccountNumberCheck::ERROR;  // Invalid IDs
-    // Modified by Jens Gecius, algo changed July 9th, 2004
-    // Exception handling
-    // This calculation, as far as I can see, is also influenced
-    // by the calculation "error" in algo02 (see below, method "B2"
-    // but I have no solution on hand.
-    //        if (9 == account[2] && 9 == account[3]) {
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	//            	number2Array("987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C
     return algo01(7, weight, false, 10, account); // Method C
 }
 AccountNumberCheck::Result method_52(int *account, int *weight, 
@@ -702,19 +701,10 @@ AccountNumberCheck::Result method_72(int *account, int *weight) {
 }
 // Added by Jens Gecius, validated with two test accountIDs
 AccountNumberCheck::Result method_73(int *account, int *weight) {
-    // Modified by Jens Gecius, algo changed December 6th, 2004
-    // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
-    //        if (account[2] == 9) {
-    //            number2Array("0987654320", weight); weight[0] = 10;
-    //            return algo01(11, weight, false, 10, account);
-    //        }
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
+
     number2Array("0001212120", weight);
     if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
 	return AccountNumberCheck::OK;
@@ -799,20 +789,10 @@ AccountNumberCheck::Result method_79(int *account, int *weight) {
     return algo01(10, weight, true, checkIndex, account);
 }
 AccountNumberCheck::Result method_80(int *account, int *weight) {
-    // exception:
-    // Modified by Jens Gecius, algo changed June 8th, 2004
-    // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
-    // if (9 == account[2] && 9 == account[3]) {
-    //	  number2Array("987654320", weight); weight[0] = 10;
-    //	  return algo01(11, weight, false, 10, account);
-    //	}
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
+
     // var 1
     number2Array("0000212120", weight);
     if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
@@ -822,20 +802,11 @@ AccountNumberCheck::Result method_80(int *account, int *weight) {
     return algo01(7, weight, true, 10, account);
 }
 AccountNumberCheck::Result method_81(int *account, int *weight) {
-    // Modified by Jens Gecius, validated with three test accountIDs
-    // Modified by Jens Gecius, algo changed September 6th, 2004
-    // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
+
     number2Array("0007654320", weight); weight[0] = 10;
-    //	if (9 != account[2]) {
-    //	  weight[1] = 0; weight[2] = 0;
-    //	}
     return algo01(11, weight, false, 10, account);
 }
 AccountNumberCheck::Result method_82(int *account, int *weight) {
@@ -872,20 +843,9 @@ AccountNumberCheck::Result method_83(int *account, int *weight) {
     return algo01(11, weight, false, 10, account);	
 }
 AccountNumberCheck::Result method_84(int *account, int *weight) {
-    // exception:
-    // Modified by Jens Gecius, algo changed September 6th, 2004
-    // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
-    //	if (9 == account[2] && 9 == account[3]) {
-    //	  number2Array("987654320", weight); weight[0] = 10;
-    //	  return algo01(11, weight, false, 10, account);	  	  
-    //	}
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
 
     // var 1
     number2Array("0000654320", weight);
@@ -919,20 +879,9 @@ AccountNumberCheck::Result method_85(int *account, int *weight) {
     return algo01(7, weight, false, 10, account);
 }
 AccountNumberCheck::Result method_86(int *account, int *weight) {
-    // exception:
-    // Modified by Jens Gecius, algo changed September 6th, 2004
-    // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
-    //	if (9 == account[2]) {
-    //	  number2Array("987654320", weight); weight[0] = 10;
-    //	  return algo01(11, weight, false, 10, account);	  
-    //	}
+    // exception "Ausnahme f. Sachkonten"
+    if (9 == account[2])
+	return method_51_exception(account,weight);
 
     // var 1
     number2Array("0001212120", weight);
@@ -947,19 +896,10 @@ AccountNumberCheck::Result method_87(int *account, int *weight,
 				     const std::string& accountId, const std::string& bankId) {
     // Modified by Jens Gecius, algo changed September 6th, 2004
     // Checked with (positive only) Bundesbank-Testnumbers
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
+    if (9 == account[2])
+	return method_51_exception(account,weight);		// exception "Ausnahme f. Sachkonten"
+
     // method a, b, c not verified in regard of changes (Sep 6th, 2004)!
-    //	if (9 == account[2]) {
-    // calc with method 10
-    //	  number2Array("987654320", weight); weight[0] = 10;
-    //	  return algo01(11, weight, false, 10, account);
-    //	}
 
     // method a
     if (AccountNumberCheck::OK == algo06(accountId))
@@ -1064,7 +1004,7 @@ AccountNumberCheck::Result method_93(int *account, int *weight) {
     int result = algo03(7, weight, false, account, 0, 9);
     if (result == 0)
 	result = 7;
-    if (account[checkIndex] == (7 - result))
+    if (account[checkIndex - 1] == (7 - result))
 	return AccountNumberCheck::OK;
     return AccountNumberCheck::ERROR;
 }
@@ -1132,11 +1072,14 @@ AccountNumberCheck::Result method_A0(int *account, int *weight) {
     if ("0000000" == array2Number(account).substr(0, 7))
 	return AccountNumberCheck::OK;
     // Modified by Jens Gecius, NOT validated as no bank seems to use it
+    // fixed by Alexander Kurz 2006-05-17, validated with published numbers
     number2Array("0000058420", weight); weight[4] = 10;
     int result = algo03a(weight, false, account, 0, 9);
     result = result % 11;
     if (result == 0 || result == 1)
-	result = 11;
+	result = 0;
+    else
+	result = 11 - result;
     if (account[9] == result)
 	return AccountNumberCheck::OK;
     return AccountNumberCheck::ERROR;
@@ -1199,7 +1142,7 @@ AccountNumberCheck::Result method_A4(int *account, int *weight) {
     int result = algo03(7, weight, false, account, 0, 9);
     if (result == 0)
 	result = 7;
-    if (account[checkIndex] == (7 - result))
+    if (account[checkIndex - 1] == (7 - result))
 	return AccountNumberCheck::OK;
     return AccountNumberCheck::ERROR;
 }
@@ -1229,36 +1172,15 @@ AccountNumberCheck::Result method_A7(int *account, int *weight) {
     return algo01(10, weight, false, 10, account);
 }
 AccountNumberCheck::Result method_A8(int *account, int *weight) {
-    // Modified by Jens Gecius, indirect change due to method 81 (see there)
-    // as of September 6th, 2004
-    // Checked with Bundesbank-Testnumbers; could someone investigate,
-    // why test-number 3199500502 is shown correct, although it should be wrong?
-    //	number2Array("0987654320", weight); weight[0] = 10;
-    //	if (9 != account[2])
-    //	  weight[1] = weight[2] = 0;
-    if (9 == account[2]) {
-	number2Array("0087654320", weight);
-	if (algo01(11, weight, false, 10, account))
-	    return AccountNumberCheck::OK; // Variant 1
-	number2Array("0987654320", weight); weight[0] = 10;
-	return algo01(11, weight, false, 10, account); // Variant 2
-    }		   // Exception to method C, Method 51
+    // revised method A8 according to the description published in March 7 2005
+    // tested with testnumbers for method A8 and exception/51
+    if (9 == account[2])
+	return method_51_exception(account,weight);		// exception "Ausnahme f. Sachkonten"
     number2Array("0007654320", weight);
     if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
-	return AccountNumberCheck::OK;
-    if (account[2] == 9)
-	return AccountNumberCheck::ERROR;
-    // Further test according to method 73 (see there), without account[2]==9
-    // (not tested in variant 2)
+	return AccountNumberCheck::OK;			// variant 1: weight modified method 06
     number2Array("0001212120", weight);
-    if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
-	return AccountNumberCheck::OK;
-    number2Array("0000212120", weight);
-    if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
-	return AccountNumberCheck::OK;
-    return algo01(7, weight, true, 10, account);
-    //        number2Array("0001212120", weight);
-    //        return algo01(10,weight, true, 10, account);
+    return algo01(10, weight, true, 10, account);	// variant 2: weight modified method 00
 }
 AccountNumberCheck::Result method_A9(int *account, int *weight) {
     number2Array("1731731730", weight);
@@ -1325,27 +1247,24 @@ AccountNumberCheck::Result method_B3(int *account, int *weight) {
 }
 // B4 and B5 Added by Alexander Kurz
 // new method as of March 7th, 2005, checked with Bundesbank-Testnumbers
+// note: this is an implementation of method B4 according to the
+//       corrected description published in zv_pz200503II.pdf
 AccountNumberCheck::Result method_B4(int *account, int *weight) {
-    if (account[0] == 9) {
-	number2Array("2121212120", weight);
-	return algo01(10, weight, true, 10, account);
-    } // variant 1 (method "00")
+    if (account[0] == 9)
+	return method_00(account,weight);	// variant 1
     if (account[0] < 9) {
 	number2Array("0987654320", weight); weight[0] = 10;
 	return algo01(11, weight, false, 10, account);
-    } // variant 2 (method "02")
+    } // variant 2 (method "02" using modified weight)
     return AccountNumberCheck::ERROR; // should never happen, to be on the safe side
 }
 // new method B5 as of June 6th, 2005, checked with Bundesbank-Testnumbers
 AccountNumberCheck::Result method_B5(int *account, int *weight) {
-    number2Array("1371371370", weight);
-    if (AccountNumberCheck::OK == algo01(10, weight, false, 10, account))
-	return AccountNumberCheck::OK; // variant 1 (method "05")
+    if (AccountNumberCheck::OK == method_05(account,weight))
+	return AccountNumberCheck::OK;		// variant 1
     if (account[0] == 8 || account[0] == 9)
 	return AccountNumberCheck::ERROR;
-    number2Array("2121212120", weight);
-    return algo01(10, weight, true, 10, account);
-    // variant 1 (method "00")
+    return method_00(account,weight);		// variant 2
 }
 // B6, B7 and B8 Added by Alexander Kurz
 // new method as of September 5th, 2005, checked with Bundesbank-Testnumbers
@@ -1402,6 +1321,26 @@ AccountNumberCheck::Result method_C0(int *account, int *weight,
 	    return AccountNumberCheck::OK;
     return method_20(account,weight);	// variant 2
 }
+// new method C1 and C2 as of June 5th, 2006, checked with Bundesbank-Testnumbers
+AccountNumberCheck::Result method_C1(int *account, int *weight) {
+    if (account[0] != 5)
+       return method_17(account,weight);       // variant 1
+    // variant 2 is a modified version of method_17
+    number2Array("1212121210", weight);
+    int tmp = algo03a(weight, true, account, 0, 9);
+    tmp = (tmp - 1) % 11;
+    tmp = 10 - tmp;
+    if (10 == tmp)
+	tmp = 0;
+    if ( account[9] == tmp )
+	return AccountNumberCheck::OK;
+    return AccountNumberCheck::ERROR;
+}
+AccountNumberCheck::Result method_C2(int *account, int *weight) {
+    if (AccountNumberCheck::OK == method_22(account,weight) )	// variant 1
+	return AccountNumberCheck::OK;
+    return method_00(account,weight);	// variant 2
+}
 
 struct method_func_s {
     const char *str;
@@ -1523,6 +1462,8 @@ const struct method_func_s cb_funcs[] = {
   { "B7", method_B7},
   { "B8", method_B8},
   { "B9", method_B9},
+  { "C1", method_C1},
+  { "C2", method_C2},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
